NoteModificationType

Enum NoteModificationType 

pub enum NoteModificationType {
Show 48 variants Accent, BrassBend, DetachedLegato, Doit, DoubleTongue, DownBow, Dynamic { dynamic: Dynamic, }, Falloff, Fermata, Fingernails, Flip, Glissando { from_current: bool, going_up: bool, }, Golpe, Grace { acciaccatura: bool, }, HalfMuted, Handbell { technique: HandbellTechnique, }, HarmonMute { open: bool, half: bool, }, Haydn, Heel, Hole { open: bool, half: bool, }, Marcato, Mordent { upper: bool, }, Open, Pizzicato, Plop, Portamento { from_current: bool, going_up: bool, }, Schleifer, Scoop, Sforzando, Shake, Smear, SoftAccent, Spiccato, Staccato, Staccatissimo, Stopped, Stress, Tap, Tenuto, ThumbPosition, Tie, Toe, Tremolo { relative_speed: u8, }, Trill { upper: bool, }, TripleTongue, Turn { upper: bool, delayed: bool, vertical: bool, }, Unstress, UpBow,
}
Represents a type of modification to a note.

Variants



Accent

Accent



BrassBend

Brass Bend



DetachedLegato

Detached Legato



Doit

Doit



DoubleTongue

Double Tongue



DownBow

Down Bow



Dynamic

Represents a dynamic change that only affects the current note.

Fields

dynamic: Dynamic


Falloff

Falloff



Fermata

Fermata



Fingernails

Fingernails



Flip

Flip



Glissando

Glissando Up

Fields

from_current: bool
going_up: bool


Golpe

Golpe



Grace

Grace Acciaccatura

Grace Appoggiatura

Fields

acciaccatura: bool


HalfMuted

Half Muted



Handbell

Represents a HandbellTechnique used in handbell playing.

Fields



HarmonMute

Open:

Half:

Closed:

Fields

open: bool
half: bool


Haydn

Haydn



Heel

Heel



Hole

Open:

Half:

Closed:

Fields

open: bool
half: bool


Marcato

Marcato



Mordent

Mordent Upper

Mordent Lower

Fields

upper: bool


Open

Open



Pizzicato

Pizzicato



Plop

Plop



Portamento

Portamento Up

Fields

from_current: bool
going_up: bool


Schleifer

Schleifer



Scoop

Scoop



Sforzando

Sforzando



Shake

Shake



Smear

Smear



SoftAccent

Soft Accent



Spiccato

Spiccato



Staccato

Staccato



Staccatissimo

Staccatissimo



Stopped

Stopped



Stress

Stress



Tap

Tap



Tenuto

Tenuto



ThumbPosition

Thumb Position



Tie

Tie



Toe

Toe



Tremolo

Tremolo

Fields

relative_speed: u8


Trill

Trill

Fields

upper: bool


TripleTongue

Triple Tongue



Turn

Turn Upper

Turn Lower

Vertical Turn Upper

Fields

upper: bool
delayed: bool
vertical: bool


Unstress

Unstress



UpBow

Up Bow