pub enum KeyMode {
Major,
Minor,
}Expand description
Represents the relative interval between notes in musical scale.
Variants
Major
Represents the following note intervals in semitones, starting from the root note of the corresponding key:
[2, 2, 1, 2, 2, 2, 1]
Minor
Represents the following note intervals in semitones, starting from the root note of the corresponding key:
[2, 1, 2, 2, 2, 1, 2]